@@ -137,6 +137,8 @@ class SocketHandler:
 
         return
     
+
+    # SOCKET FUNCTIONS
     def join_voice_chat(self, comId: str, chatId: str, joinType: int = 1):
         """
         Joins a Voice Chat
@@ -153,7 +155,7 @@ class SocketHandler:
                 "ndcId": int(comId),
                 "threadId": chatId,
                 "joinRole": joinType,
-                "id": "2154531"  # Need to change?
+                "id": "2154531"
             },
             "t": 112
         })
@@ -176,7 +178,7 @@ class SocketHandler:
                 "threadId": chatId,
                 "joinRole": joinType,
                 "channelType": 5,
-                "id": "2154531"  # Need to change?
+                "id": "2154531"
             },
             "t": 108
         })
@@ -202,7 +204,7 @@ class SocketHandler:
                     "ndcId": comId,
                     "threadId": chatId,
                     "joinRole": joinType,
-                    "id": "2154531"  # Need to change?
+                    "id": "2154531"
                 },
                 "t": 112
             })
@@ -215,7 +217,7 @@ class SocketHandler:
                 "ndcId": comId,
                 "threadId": chatId,
                 "joinRole": joinType,
-                "id": "2154531"  # Need to change?
+                "id": "2154531"
             },
             "t": 112
         })
@@ -226,7 +228,7 @@ class SocketHandler:
                 "ndcId": comId,
                 "threadId": chatId,
                 "channelType": 1,
-                "id": "2154531"  # Need to change?
+                "id": "2154531"
             },
             "t": 108
         })
@@ -241,13 +243,14 @@ class SocketHandler:
                 "ndcId": comId,
                 "threadId": chatId,
                 "joinRole": joinType,
-                "id": "2154531"  # Need to change?
+                "id": "2154531"
             },
             "t": 112
         })
         self.send(data)
     
-    def send_action(self, comId: str, actions: list, chatId: str = None, blogId: str = None, quizId: str = None, lastAction: bool = False):
+    def send_action(self, comId: str, actions: list, chatId: str = None, chatType: int = 2,
+            blogId: str = None, quizId: str = None, lastAction: bool = False):
         # Action List
         # - Browsing
         # - Chatting
@@ -261,7 +264,6 @@ class SocketHandler:
                 "actions": actions,
                 "target": f"ndc://x{comId}/",
                 "ndcId": int(comId),
-                "params": {},
                 "id": "831046"
             },
             "t": t
@@ -269,12 +271,14 @@ class SocketHandler:
 
         if blogId is not None or quizId is not None and chatId is None:
             data["target"] = f"ndc://x{comId}/blog/{blogId}"
+
+            if blogId or quizId: data["params"] = {}
             if blogId is not None: data["params"]["blogType"] = 0
             if quizId is not None: data["params"]["blogType"] = 6
         
         if chatId is not None and blogId is None and quizId is None:
             data["target"] = f"ndc://x{comId}/chat-thread/{chatId}"
-            # This working, but i not finish this.
+            if chatType: data["params"] = {"threadType": chatType}
 
         return self.send(json.dumps(data))
 
